@@ -7,18 +7,18 @@ from flask import Flask, escape, render_template, send_from_directory
 
 try:
     __version__ = pkg_resources.get_distribution("brython-dev").version
-except pkg_resources.DistributionNotFound:
+except pkg_resources.DistributionNotFound:  # pragma: no cover
     __version__ = "unknown"
 
 
 def create_app(config: dict = {}) -> Flask:
     config_file = Path(config.get("CONFIG_FILE", "brython.yml")).resolve()
-    if not config_file.exists():
-        raise FileExistsError(f"{config_file} not exist")
 
-    config_yaml = {
-        k.upper(): v for k, v in yaml.safe_load(config_file.read_text()).items()
-    }
+    config_yaml = (
+        {k.upper(): v for k, v in yaml.safe_load(config_file.read_text()).items()}
+        if config_file.exists()
+        else {"NAME": "Unnamed"}
+    )
 
     proyect = Path.cwd()
     if Path(config_yaml["NAME"].lower().replace("-", "_")).is_dir():
@@ -29,7 +29,7 @@ def create_app(config: dict = {}) -> Flask:
         static_folder=str(proyect.resolve()),
         static_url_path=config_yaml.get("STATIC_URL", "/"),
     )
-    
+
     app.config.from_mapping(config_yaml)
     app.config.from_mapping(config)
 
